@@ -92,6 +92,11 @@ class PackageManager(QObject):
     def packagesWithUpdate(self) -> Set[str]:
         return self._packages_with_update_available
 
+    ## Alternative way of setting the available package updates without having to check all packages in the cloud.
+    def setPackagesWithUpdate(self, packages: Set[str]):
+        self._packages_with_update_available = packages
+        self.packagesWithUpdateChanged.emit()
+
     def checkIfPackageCanUpdate(self, package_id: str) -> bool:
         available_versions = self._available_package_versions.get(package_id)
 
@@ -291,6 +296,20 @@ class PackageManager(QObject):
 
         return all_installed_ids
 
+    ## Get a list of tuples that contain the package ID and version.
+    #  Used by the Marketplace to check which packages have updates available.
+    def getAllInstalledPackageIdsAndVersions(self) -> List[Tuple[str, str]]:
+        package_ids_and_versions = []  # type: List[Tuple[str, str]]
+        all_installed_ids = self.getAllInstalledPackageIDs()
+        for package_id in all_installed_ids:
+            package_info = self.getInstalledPackageInfo(package_id)
+            if package_info is None:
+                continue
+            if "package_version" not in package_info:
+                continue
+            package_ids_and_versions.append((package_id, package_info["package_version"]))
+        return package_ids_and_versions
+
     def getAllInstalledPackagesInfo(self) -> Dict[str, List[Dict[str, Any]]]:
 
         all_installed_ids = self.getAllInstalledPackageIDs()
@@ -514,20 +533,21 @@ class PackageManager(QObject):
     # Returns None if there is no license file found.
     def getPackageLicense(self, filename: str) -> Optional[str]:
         license_string = None
+        def is_license(zipinfo: zipfile.ZipInfo) -> bool:
+            return os.path.basename(zipinfo.filename).startswith("LICENSE")
         with zipfile.ZipFile(filename) as archive:
             # Go through all the files and use the first successful read as the result
-            for file_info in archive.infolist():
-                if file_info.filename.endswith("LICENSE"):
-                    Logger.log("d", "Found potential license file '%s'", file_info.filename)
-                    try:
-                        with archive.open(file_info.filename, "r") as f:
-                            data = f.read()
-                        license_string = data.decode("utf-8")
-                        break
-                    except:
-                        Logger.logException("e", "Failed to load potential license file '%s' as text file.",
-                                            file_info.filename)
-                        license_string = None
+            license_files = sorted(filter(is_license, archive.infolist()), key = lambda x: len(x.filename))  # Find the one with the shortest path.
+            for file_info in license_files:
+                Logger.log("d", "Found potential license file '{filename}'".format(filename = file_info.filename))
+                try:
+                    with archive.open(file_info.filename, "r") as f:
+                        data = f.read()
+                    license_string = data.decode("utf-8")
+                    break
+                except:
+                    Logger.logException("e", "Failed to load potential license file '%s' as text file.", file_info.filename)
+                    license_string = None
         return license_string
 
     ##  Find the package files by package_id by looking at the installed folder
