@@ -28,8 +28,8 @@ from UM.Settings.Validator import Validator
 #   This class provides the property values through QObject dynamic properties so that they
 #   are available from QML.
 class SettingPropertyProvider(QObject):
-    def __init__(self, parent = None, *args, **kwargs) -> None:
-        super().__init__(parent = parent, *args, **kwargs)
+    def __init__(self, parent = None) -> None:
+        super().__init__(parent = parent)
 
         self._property_map = QQmlPropertyMap(self)
 
@@ -43,7 +43,7 @@ class SettingPropertyProvider(QObject):
         self._remove_unused_value = True
         self._validator = None  # type: Optional[Validator]
 
-        self._update_timer = QTimer()
+        self._update_timer = QTimer(self)
         self._update_timer.setInterval(100)
         self._update_timer.setSingleShot(True)
         self._update_timer.timeout.connect(self._update)
@@ -51,6 +51,9 @@ class SettingPropertyProvider(QObject):
         self.storeIndexChanged.connect(self._storeIndexChanged)
 
     def setContainerStack(self, stack: Optional[ContainerStack]) -> None:
+        if self._stack == stack:
+            return  # Nothing to do, attempting to set stack to the same value.
+
         if self._stack:
             self._stack.propertiesChanged.disconnect(self._onPropertiesChanged)
             self._stack.containersChanged.disconnect(self._containersChanged)
@@ -82,6 +85,7 @@ class SettingPropertyProvider(QObject):
 
     ##  Emitted when the containerStackId property changes.
     containerStackIdChanged = pyqtSignal()
+
     ##  The ID of the container stack we should query for property values.
     @pyqtProperty(str, fset = setContainerStackId, notify = containerStackIdChanged)
     def containerStackId(self) -> str:
@@ -241,6 +245,10 @@ class SettingPropertyProvider(QObject):
             return None
         return value
 
+    @pyqtSlot(str, result = str)
+    def getPropertyValueAsString(self, property_name: str) -> str:
+        return self._getPropertyValue(property_name)
+
     @pyqtSlot(int)
     def removeFromContainer(self, index: int) -> None:
         current_stack = self._stack
@@ -299,7 +307,14 @@ class SettingPropertyProvider(QObject):
         if key != self._key:
             if key in self._relations:
                 self._value_used = None
-                self.isValueUsedChanged.emit()
+                try:
+                    self.isValueUsedChanged.emit()
+                except RuntimeError:
+                    # QtObject has been destroyed, no need to handle the signals anymore.
+                    # This can happen when the QtObject in C++ has been destroyed, but the python object hasn't quite
+                    # caught on yet. Once we call any signals, it will cause a runtimeError since all the underlying
+                    # logic to emit pyqtSignals is gone.
+                    return
             return
 
         has_values_changed = False
@@ -308,11 +323,25 @@ class SettingPropertyProvider(QObject):
                 continue
 
             has_values_changed = True
-            self._property_map.insert(property_name, self._getPropertyValue(property_name))
+            try:
+                self._property_map.insert(property_name, self._getPropertyValue(property_name))
+            except RuntimeError:
+                # QtObject has been destroyed, no need to handle the signals anymore.
+                # This can happen when the QtObject in C++ has been destroyed, but the python object hasn't quite
+                # caught on yet. Once we call any signals, it will cause a runtimeError since all the underlying
+                # logic to emit pyqtSignals is gone.
+                return
 
         self._updateStackLevels()
         if has_values_changed:
-            self.propertiesChanged.emit()
+            try:
+                self.propertiesChanged.emit()
+            except RuntimeError:
+                # QtObject has been destroyed, no need to handle the signals anymore.
+                # This can happen when the QtObject in C++ has been destroyed, but the python object hasn't quite
+                # caught on yet. Once we call any signals, it will cause a runtimeError since all the underlying
+                # logic to emit pyqtSignals is gone.
+                return
 
     def _update(self, container = None):
         if not self._stack or not self._watched_properties or not self._key:
@@ -332,7 +361,12 @@ class SettingPropertyProvider(QObject):
         self.isValueUsedChanged.emit()
 
     def _updateDelayed(self, container = None):
-        self._update_timer.start()
+        try:
+            self._update_timer.start()
+        except RuntimeError:
+            # Sometimes the python object is not yet deleted, but the wrapped part is already gone.
+            # In that case there is nothing else to do but ignore this.
+            pass
 
     def _containersChanged(self, container = None):
         self._updateDelayed(container = container)
