@@ -22,6 +22,9 @@ from math import log
 from operator import add, eq, ne, gt, ge, lt, le, iadd
 from textwrap import dedent
 
+from typing import Any, Callable
+
+
 ###############################################################################
 # BEGIN Python 2/3 Shims
 ###############################################################################
@@ -49,6 +52,46 @@ else:
         from _dummy_thread import get_ident
 
 
+def _make_cmp(seq_op: Callable[[Any, Any], bool], symbol: str, doc: str) -> Callable:
+    "Make comparator method."
+    def comparer(one: "SortedList", other: "SortedList") -> bool:
+        "Compare method for sorted list and sequence."
+        if not isinstance(other, Sequence):
+            return NotImplemented
+
+        one_len = one._len
+        len_other = len(other)
+
+        if one_len != len_other:
+            if seq_op is eq:
+                return False
+            if seq_op is ne:
+                return True
+
+        for alpha, beta in zip(one, other):
+            if alpha != beta:
+                return seq_op(alpha, beta)
+
+        return seq_op(one_len, len_other)
+
+    seq_op_name = seq_op.__name__
+    comparer.__name__ = '__{0}__'.format(seq_op_name)
+    doc_str = """Return true if and only if sorted list is {0} `other`.
+
+    ``sl.__{1}__(other)`` <==> ``sl {2} other``
+
+    Comparisons use lexicographical order as with sequences.
+
+    Runtime complexity: `O(n)`
+
+    :param other: `other` sequence
+    :return: true if sorted list is {0} `other`
+
+    """
+    comparer.__doc__ = dedent(doc_str.format(doc, seq_op_name, symbol))
+    return comparer
+
+
 def recursive_repr(fillvalue='...'):
     "Decorator to make a repr function return fillvalue for a recursive call."
     # pylint: disable=missing-docstring
@@ -1531,53 +1574,13 @@ class SortedList(MutableSequence):
         return self
 
 
-    def __make_cmp(seq_op, symbol, doc):
-        "Make comparator method."
-        def comparer(self, other):
-            "Compare method for sorted list and sequence."
-            if not isinstance(other, Sequence):
-                return NotImplemented
-
-            self_len = self._len
-            len_other = len(other)
-
-            if self_len != len_other:
-                if seq_op is eq:
-                    return False
-                if seq_op is ne:
-                    return True
-
-            for alpha, beta in zip(self, other):
-                if alpha != beta:
-                    return seq_op(alpha, beta)
-
-            return seq_op(self_len, len_other)
-
-        seq_op_name = seq_op.__name__
-        comparer.__name__ = '__{0}__'.format(seq_op_name)
-        doc_str = """Return true if and only if sorted list is {0} `other`.
-
-        ``sl.__{1}__(other)`` <==> ``sl {2} other``
-
-        Comparisons use lexicographical order as with sequences.
-
-        Runtime complexity: `O(n)`
-
-        :param other: `other` sequence
-        :return: true if sorted list is {0} `other`
-
-        """
-        comparer.__doc__ = dedent(doc_str.format(doc, seq_op_name, symbol))
-        return comparer
-
-
-    __eq__ = __make_cmp(eq, '==', 'equal to')
-    __ne__ = __make_cmp(ne, '!=', 'not equal to')
-    __lt__ = __make_cmp(lt, '<', 'less than')
-    __gt__ = __make_cmp(gt, '>', 'greater than')
-    __le__ = __make_cmp(le, '<=', 'less than or equal to')
-    __ge__ = __make_cmp(ge, '>=', 'greater than or equal to')
-    __make_cmp = staticmethod(__make_cmp)  # type: ignore
+    __eq__ = _make_cmp(eq, '==', 'equal to')
+    __ne__ = _make_cmp(ne, '!=', 'not equal to')
+    __lt__ = _make_cmp(lt, '<', 'less than')
+    __gt__ = _make_cmp(gt, '>', 'greater than')
+    __le__ = _make_cmp(le, '<=', 'less than or equal to')
+    __ge__ = _make_cmp(ge, '>=', 'greater than or equal to')
+    __make_cmp = staticmethod(_make_cmp)  # type: ignore
 
 
     @recursive_repr()
