@@ -10,6 +10,7 @@ from typing import Any, TYPE_CHECKING, cast
 
 from UM.Logger import Logger
 
+from UM.Version import Version
 from UM.View.GL.FrameBufferObject import FrameBufferObject
 from UM.View.GL.ShaderProgram import ShaderProgram
 from UM.View.GL.ShaderProgram import InvalidShaderProgramError
@@ -87,17 +88,23 @@ class OpenGL:
         elif "intel" in vendor_string:
             self._gpu_vendor = OpenGL.Vendor.Intel
 
+        self._gpu_type = "Unknown"  # type: str
         # WORKAROUND: Cura/#1117 Cura-packaging/12
         # Some Intel GPU chipsets return a string, which is not undecodable via PyQt5.
         # This workaround makes the code fall back to a "Unknown" renderer in these cases.
         try:
-            self._gpu_type = self._gl.glGetString(self._gl.GL_RENDERER) #type: str
+            self._gpu_type = self._gl.glGetString(self._gl.GL_RENDERER)
         except UnicodeDecodeError:
             Logger.log("e", "DecodeError while getting GL_RENDERER via glGetString!")
-            self._gpu_type = "Unknown" #type: str
 
         self._opengl_version = self._gl.glGetString(self._gl.GL_VERSION) #type: str
 
+        self._opengl_shading_language_version = Version("0.0")  # type: Version
+        try:
+            self._opengl_shading_language_version = Version(self._gl.glGetString(self._gl.GL_SHADING_LANGUAGE_VERSION))
+        except:
+            self._opengl_shading_language_version = Version("1.0")
+
         if not self.hasFrameBufferObjects():
             Logger.log("w", "No frame buffer support, falling back to texture copies.")
 
@@ -105,6 +112,7 @@ class OpenGL:
         Logger.log("d", "OpenGL Version:  %s", self._opengl_version)
         Logger.log("d", "OpenGL Vendor:   %s", self._gl.glGetString(self._gl.GL_VENDOR))
         Logger.log("d", "OpenGL Renderer: %s", self._gpu_type)
+        Logger.log("d", "GLSL Version:    %s", self._opengl_shading_language_version)
 
     ##  Check if the current OpenGL implementation supports FrameBuffer Objects.
     #
@@ -118,6 +126,12 @@ class OpenGL:
     def getOpenGLVersion(self) -> str:
         return self._opengl_version
 
+    ##  Get the current OpenGL shading language version.
+    #
+    #   \return Shading language version of OpenGL
+    def getOpenGLShadingLanguageVersion(self) -> "Version":
+        return self._opengl_shading_language_version
+
     ##  Get the current GPU vendor name.
     #
     #   \return Name of the vendor of current GPU
